@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.85
+// IPplan v4.86a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -1192,7 +1192,7 @@ else {
     }
    UpdateSchema($display);
    if ($display) {
-      echo "<b>#The above commands need to be executed by the administrator to update the database schema for IPplan to v4.85. There may be no commands required.</b>\n";
+      echo "<b>#The above commands need to be executed by the administrator to update the database schema for IPplan to v4.86a. There may be no commands required.</b>\n";
    }
    else {
       echo "<b>The database schema was updated</b>";
