@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.85
+// IPplan v4.86a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -616,7 +616,7 @@ function myheading($q, $title, $displaymenu=true) {
 
     insert($w,$con=container("div",array("class"=>"normalbox")));
     insert($w,$con1=container("div",array("class"=>"footerbox")));
-    insert($con1,block("IPPlan v4.85"));
+    insert($con1,block("IPPlan v4.86a"));
     return $con;
 
 }
